@@ -6,6 +6,7 @@ use 5.010000;
 use autodie;
 use Benchmark qw(:all);
 use Router::Boom;
+use Router::Boom::Method;
 use Router::Simple;
 
 my $router_boom = do {
@@ -19,6 +20,17 @@ my $router_boom = do {
     $router;
 };
 
+my $router_boom_method = do {
+    my $router = Router::Boom::Method->new();
+    $router->add(undef, '/',      'Root');
+    $router->add(undef, '/entrylist', 'EntryList');
+    $router->add(undef, "/$_", "$_") for 'a'..'z';
+    $router->add(undef, '/:user', 'User#index');
+    $router->add(undef, '/:user/:year/', 'UserBlog#year_archive');
+    $router->add(undef, '/:user/:year/:month/', 'UserBlog#month_archive');
+    $router;
+};
+
 my $router_simple = do {
     my $router = Router::Simple->new();
     $router->connect('/',      'Root');
@@ -32,8 +44,9 @@ my $router_simple = do {
 
 cmpthese(
     -1, {
-        'Router::Simple' => sub { $router_simple->match('/dankogai/2013/02') },
-        'Router::Boom'   => sub { $router_boom->match('/dankogai/2013/02') },
+        'Router::Simple'         => sub { $router_simple->match('/dankogai/2013/02') },
+        'Router::Boom'           => sub { $router_boom->match('/dankogai/2013/02') },
+        'Router::Boom::Method'   => sub { $router_boom_method->match('GET', '/dankogai/2013/02') },
     }
 );
 
